@@ -45,9 +45,10 @@ def debhelper_common_args(f, minimal=False):
     @click.option("--indep", "-i", help="Act on all arch-independent packages", is_flag=True)
     @click.option("--arch", "-a", help="Act on all arch-dependent packages", is_flag=True)
     @click.option("--package", "-p", help="Act on named package")
-    @click.option("--remaining-packages", help="Act on remaining packages only")
-    @click.option("--firstpackage", envvar="FIRSTPACKAGE")
+    @click.option("--remaining-packages", help="Act on remaining packages only", hidden=True)
+    @click.option("--firstpackage", envvar="FIRSTPACKAGE", hidden=True)
     @click.option("--create-in-sourcedir")
+    @click.option("-O--no-parallel", is_flag=True, hidden=True)
     def wrapper(*args, **kwargs):
 
         global verbose
